import os
from django.conf import settings
from django.core.mail.backends.base import BaseEmailBackend
try:
    from cPickle import dumps
except ImportError:
    from Pickle import dumps


class EmailBackend(BaseEmailBackend):
    def send_messages(self, email_messages):
        num_sent = 0
        if not email_messages:
            return
        for email_message in email_messages:
            if self._send(email_message):
                num_sent += 1
        return num_sent

    def _send(self, email_message):
        from uwsgi_mail.task import send_mail
        send_mail.spool(email_message=dumps(email_message))
        return True



from uwsgidecorators import spool
try:
    from cPickle import loads
except ImportError:
    from Pickle import loads

from django.conf import settings
from django.core.mail import get_connection

BACKEND=getattr(settings, 'UWSGI_EMAIL_BACKEND',
    'django.core.mail.backends.smtp.EmailBackend')

@spool
def send_mail(arguments):
    conn = get_connection(backend=BACKEND)
    conn.send_messages([loads(arguments['email_message'])])



from setuptools import setup
setup(
    name='django-uwsgi-mail',
    version='1.0',
    author='Jayson Reis',
    author_email='santosdosreis@gmail.com',
    description='A Django backend for e-mail delivery using uWSGI Spool to queue deliveries.',
    url='https://github.com/jaysonsantos/django-uwsgi-mail',
    packages=['uwsgi_mail'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ]
)
